watch<T> abstract method

T watch<T>(
  1. Query<T> query
)

watches the given query and returns with its value. It will reactively update the value when the query is invalidated and refetched.

Implementation

T watch<T>(Query<T> query);