CompositionEvent class sealed

Events associated with Composition lifecycle

Inheritance
Implementers

Properties

componentName String
The name of the component that emitted the event. It is used to identify the source of the event.
finalinherited
compositionKey String
The Composition.key that identifies the composition.
final
eventTime DateTime
The time when the event was emitted. It is set to the current time when the event is created.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited