CompositionSettledEvent class final
When the Composition.execute method notifies that it is settled: CompositionContainer.isSettled.
- Inheritance
-
- Object
- Event
- CompositionEvent
- CompositionSettledEvent
Constructors
- CompositionSettledEvent({required String compositionKey})
Properties
- componentName → String
-
The name of the component that emitted the event. It is used to identify the source of the event.
finalinherited
- compositionKey → String
-
The
Composition.keythat identifies the composition.finalinherited - eventTime → DateTime
-
The time when the event was emitted. It is set to the current time when the event is created.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited