Event class sealed
A base class for all events that can be emitted by the world. It contains the common properties of all events, such as the time of the event and the name of the component that emitted the event.
- Implementers
Properties
- componentName → String
-
The name of the component that emitted the event. It is used to identify the source of the event.
final
- eventTime → DateTime
-
The time when the event was emitted. It is set to the current time when the event is created.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited